nestcheck
=========
                        _______________________________________
           .---.__     /                                       \
          /  /6|__\ --=  Check your nest(ed sampling results)! |
          \  \/--`     \_______________________________________/
          /  \\
         /    )\
        /  _.' /
       //~`\\-'        .-.
      //   (~))   .-. /   \.-.
     /    ~~~~~  /   \    /   \ ~~~~~
     jgs   ~~~~~~~~~~~~~~~~~~~~~~~~~
              ~~~~~~~~~~~~~~~~~~~
[![Build Status](https://travis-ci.org/ejhigson/nestcheck.svg?branch=master)](https://travis-ci.org/ejhigson/nestcheck)
[![Coverage Status](https://coveralls.io/repos/github/ejhigson/nestcheck/badge.svg?branch=master)](https://coveralls.io/github/ejhigson/nestcheck?branch=master)
[![Documentation Status](https://readthedocs.org/projects/nestcheck/badge/?version=latest)](http://nestcheck.readthedocs.io/en/latest/?badge=latest)
[![Maintainability](https://api.codeclimate.com/v1/badges/7fdfe74eb8256020c780/maintainability)](https://codeclimate.com/github/ejhigson/nestcheck/maintainability)
[![MIT License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/ejhigson/nestcheck/LICENSE)

## Read the documentation at [http://nestcheck.readthedocs.io](http://nestcheck.readthedocs.io).
<!-- ASCII art bird adapted from http://www.oocities.org/spunk1111/birds.htm#parrot --!>
